pub enum PreparedEvaluationSession {
SchemaFree(EvaluationSession<SchemaFree>),
SchemaEnforcing(EvaluationSession<SchemaEnforcing>),
}Expand description
One frozen authorization generation, retaining its schema mode.
Variants
SchemaFree(EvaluationSession<SchemaFree>)
A frozen generation without schema enforcement.
SchemaEnforcing(EvaluationSession<SchemaEnforcing>)
A frozen generation with schema enforcement.
Implementations
Sourceimpl PreparedEvaluationSession
impl PreparedEvaluationSession
Sourcepub fn version(&self) -> PolicyVersion
pub fn version(&self) -> PolicyVersion
Return the exact version used by every evaluation in this session.
Sourcepub fn evaluate(&self, request: &Request) -> Result<Decision, PolicyError>
pub fn evaluate(&self, request: &Request) -> Result<Decision, PolicyError>
Evaluate a request, returning Core errors for invalid request data.
Sourcepub fn evaluate_with_context(
&self,
request: &Request,
context: &RequestContext,
) -> Result<Decision, PolicyError>
pub fn evaluate_with_context( &self, request: &Request, context: &RequestContext, ) -> Result<Decision, PolicyError>
Evaluate with explicit context, returning Core validation/evaluation errors.