pub fn check_module(path: impl AsRef<Path>) -> Result<PolicyCheck>Expand description
Check one module in isolation. Declared imports are accepted but need not be present.
pub fn check_module(path: impl AsRef<Path>) -> Result<PolicyCheck>Check one module in isolation. Declared imports are accepted but need not be present.