pub struct BundleBuilder { /* private fields */ }Expand description
Compiler entry point for an organization bundle manifest.
Implementations
Sourceimpl BundleBuilder
impl BundleBuilder
pub fn from_manifest(path: impl AsRef<Path>) -> Result<Self>
pub fn manifest(&self) -> &BundleManifest
pub fn deny_warnings(self, deny: bool) -> Self
Sourcepub fn check(&self) -> Result<PolicyCheck>
pub fn check(&self) -> Result<PolicyCheck>
Validate the complete source bundle without emitting an archive.
Sourcepub fn build(&self, signing_key: Option<&SigningKey>) -> Result<BundleArchive>
pub fn build(&self, signing_key: Option<&SigningKey>) -> Result<BundleArchive>
Validate and compile a deterministic archive, optionally signing it.